Puzzles
=======

SokobanPuzzle
-------------

.. autoclass:: sokoenginepy.io.SokobanPuzzle
    :members:
    :show-inheritance:
    :special-members: __init__


HexobanPuzzle
-------------

.. autoclass:: sokoenginepy.io.HexobanPuzzle
    :members:
    :show-inheritance:
    :special-members: __init__


TriobanPuzzle
-------------

.. autoclass:: sokoenginepy.io.TriobanPuzzle
    :members:
    :show-inheritance:
    :special-members: __init__


OctobanPuzzle
-------------

.. autoclass:: sokoenginepy.io.OctobanPuzzle
    :members:
    :show-inheritance:
    :special-members: __init__


CellOrientation
---------------

.. autoclass:: sokoenginepy.io.CellOrientation
    :members:
    :undoc-members:


Puzzle
------

.. autoclass:: sokoenginepy.io.Puzzle
    :members:
    :undoc-members:
    :special-members: __init__, __eq__, __ne__, __getitem__, __setitem__, __contains__
    :member-order: bysource
